@@ -53,7 +53,7 @@ MAXIMUM_MUTATION_AGE_IN_SECONDS = 180
 
 
 VARIABLE_ID_PATTERN = re.compile(r'[a-zA-Z0-9-_ ]+$')
-VARIABLE_ID_TEMPLATE_PATTERN = re.compile(r'{\s*([^}]+?)\s*}')
+VARIABLE_ID_TEMPLATE_PATTERN = re.compile(r'{\s*([^{}\'"]+?)\s*}')
 CACHED_FILE_SIZE_LIMIT_IN_BYTES = 1024
 MAXIMUM_FILE_CACHE_LENGTH = 256
 
