@@ -153,7 +153,6 @@ class AutomationRoutes():
             'title_text': configuration.get('name', 'Automations'),
             'automations': guard.get_automation_definitions(configuration),
             'css_uris': configuration.css_uris,
-            'css_text': configuration.css_text,
             'mutation_uri': MUTATION_ROUTE.format(uri=''),
             'mutation_timestamp': time(),
         }
@@ -183,13 +182,14 @@ class AutomationRoutes():
 
     def run_automation(self, request):
         automation_definition = self.get_automation_definition_from(request)
-        guard = AuthorizationGuard(request, self.safe)
+        guard = AuthorizationGuard(
+            request, self.safe, automation_definition.identities_by_token)
         if not guard.check('run_automation', automation_definition):
             raise HTTPForbidden
         variable_definitions = automation_definition.get_variable_definitions(
             'input')
         try:
-            data_by_id = dict(request.params) or request.json_body
+            data_by_id = request.json_body
         except json.JSONDecodeError:
             data_by_id = {}
         try:
@@ -211,15 +211,14 @@ class AutomationRoutes():
 
     def see_automation(self, request):
         automation_definition = self.get_automation_definition_from(request)
-        guard = AuthorizationGuard(request, self.safe)
+        guard = AuthorizationGuard(
+            request, self.safe, automation_definition.identities_by_token)
         if not guard.check('see_automation', automation_definition):
             raise HTTPForbidden
         design_name = automation_definition.get_design_name('automation')
         automation_uri = automation_definition.uri
         if design_name == 'none':
-            d = {
-                'css_uris': automation_definition.css_uris,
-                'css_text': automation_definition.css_text}
+            d = {'css_uris': automation_definition.css_uris}
             mutation_reference_uri = automation_uri
         else:
             batch_definition = automation_definition.batch_definitions[0]
@@ -242,7 +241,8 @@ class AutomationRoutes():
 
     def see_automation_batch_mode(self, request):
         automation_definition = self.get_automation_definition_from(request)
-        guard = AuthorizationGuard(request, self.safe)
+        guard = AuthorizationGuard(
+            request, self.safe, automation_definition.identities_by_token)
         is_match = guard.check('see_batch', automation_definition)
         if not is_match:
             raise HTTPForbidden
@@ -257,7 +257,8 @@ class AutomationRoutes():
 
     def see_automation_batch_mode_variable(self, request):
         automation_definition = self.get_automation_definition_from(request)
-        guard = AuthorizationGuard(request, self.safe)
+        guard = AuthorizationGuard(
+            request, self.safe, automation_definition.identities_by_token)
         is_match = guard.check('see_batch', automation_definition)
         if not is_match:
             raise HTTPForbidden
@@ -375,9 +376,7 @@ def __get_mode_jinja_dictionary(
     main_text = get_html_from_markdown(VARIABLE_ID_TEMPLATE_PATTERN.sub(
         render_html, template_text))
     return m | {
-        'css_text': '\n'.join([
-            __get_css_text(design_name, for_embed, for_print),
-            automation_definition.css_text]),
+        'css_text': __get_css_text(design_name, for_embed, for_print),
         'main_text': main_text,
         'js_text': '\n'.join(m['js_texts']),
         'for_embed': for_embed,
@@ -398,8 +397,10 @@ def __get_css_text(design_name, for_embed, for_print):
 def _render_html(
         match, variable_definitions, batch, m, i, root_uri, mode_name,
         design_name, for_print):
-    matching_text = match.group(0)
-    terms = match.group(1).split('|')
+    matching_inner_text = match.group(1)
+    if matching_inner_text == 'ROOT_URI':
+        return root_uri
+    terms = matching_inner_text.split('|')
     variable_id = terms[0].strip()
     try:
         variable_definition = find_item(
@@ -407,7 +408,8 @@ def _render_html(
     except StopIteration:
         L.warning(
             '%s variable in template but not in configuration', variable_id)
-        return matching_text
+        matching_outer_text = match.group(0)
+        return matching_outer_text
     view = VariableView.get_from(variable_definition)
     element = Element(
         f'v{next(i)}', root_uri, mode_name, design_name, for_print, terms[1:])
