@@ -9,9 +9,10 @@ from ..routines.batch import DiskBatch
 
 class AuthorizationGuard():
 
-    def __init__(self, request, safe):
+    def __init__(self, request, safe, identities_by_token=None):
         self._request = request
         self._safe = safe
+        self._identities_by_token = identities_by_token or {}
 
     @cached_property
     def identities(self):
@@ -20,10 +21,10 @@ class AuthorizationGuard():
         token = get_token(request)
         if token:
             try:
-                identities.update(self._safe.get(
-                    token), ip_address=request.remote_addr)
+                d = self._safe.get(token)
             except KeyError:
-                pass
+                d = self._identities_by_token.get(token, {})
+            identities.update(d, ip_address=request.client_addr)
         return identities
 
     def check(self, permission_id, configuration):
