@@ -6,9 +6,10 @@ from configparser import ConfigParser
 from datetime import timedelta
 from logging import getLogger
 from os import environ
-from os.path import basename, relpath
+from os.path import basename, relpath, splitext
 from pathlib import Path
 from string import Template
+from time import time
 
 import tomli
 from invisibleroads_macros_log import format_path
@@ -29,6 +30,7 @@ from ..constants import (
     MODE_NAMES,
     PRINTER_BY_NAME,
     RUN_ROUTE,
+    STYLE_ROUTE,
     VARIABLE_ID_PATTERN,
     VARIABLE_ID_TEMPLATE_PATTERN,
     VIEW_BY_NAME)
@@ -285,6 +287,7 @@ class ButtonDefinition(Definition):
 class TokenDefinition(Definition):
 
     def _initialize(self, kwargs):
+        self.automation_folder = kwargs['automation_folder']
         self._validation_functions = [
             validate_token_identifiers,
         ]
@@ -480,6 +483,7 @@ def validate_variables(configuration):
 
 
 def validate_variable_views(configuration):
+    # TODO: Validate variable view configurations
     initialize_view_by_name()
     for view_name in configuration.___view_names:
         try:
@@ -584,24 +588,31 @@ def validate_scripts(configuration):
 def validate_display_styles(configuration):
     display_dictionary = get_dictionary(configuration, 'display')
     automation_folder = configuration.folder
+    automation_index = configuration.index
+    automation_uri = configuration.uri
+    reference_time = time()
     style_definitions = []
-    css_texts = []
     for raw_style_definition in get_dictionaries(
             display_dictionary, 'styles'):
         style_definition = StyleDefinition(raw_style_definition)
         style_uri = style_definition.uri
         if '//' not in style_uri:
-            path = automation_folder / style_definition.path
+            style_path = style_definition.path
+            path = automation_folder / style_path
             if not path.exists():
                 raise CrossComputeConfigurationError(
                     f'{path} not found for style')
-            css_texts.append(path.read_text().rstrip())
-            continue
+            style_name = format_slug(
+                f'{splitext(style_path)[0]}-{reference_time}')
+            style_uri = STYLE_ROUTE.format(style_name=style_name)
+            if automation_index > 0:
+                style_uri = automation_uri + style_uri
+            style_definition.path = style_path
+            style_definition.uri = style_uri
         style_definitions.append(style_definition)
     return {
         'style_definitions': style_definitions,
         'css_uris': [_.uri for _ in style_definitions],
-        'css_text': '\n'.join(css_texts) + '\n' if css_texts else '',
     }
 
 
@@ -642,8 +653,9 @@ def validate_display_buttons(configuration):
 
 def validate_authorization(configuration):
     authorization_dictionary = get_dictionary(configuration, 'authorization')
-    token_definitions = [TokenDefinition(_) for _ in get_dictionaries(
-        authorization_dictionary, 'tokens')]
+    token_definitions = [TokenDefinition(
+        _, automation_folder=configuration.folder,
+    ) for _ in get_dictionaries(authorization_dictionary, 'tokens')]
     identities_by_token = {
         token: identities for _ in token_definitions
         for token, identities in _.identities_by_token.items()}
@@ -900,13 +912,10 @@ def validate_token_identifiers(token_dictionary):
         token_path = token_dictionary['path']
     except KeyError as e:
         raise CrossComputeConfigurationError(f'{e} required for each token')
-    token_path = Path(token_path)
-    suffix = token_path.suffix
+    path = Path(token_dictionary.automation_folder, token_path)
+    suffix = path.suffix
     if suffix == '.yml':
-        yaml = YAML()
-        d = yaml.load(token_path)
-    elif suffix == '.json':
-        d = json.load(token_path.open('rt'))
+        d = load_raw_configuration_yaml(path)
     else:
         raise CrossComputeConfigurationError(
             f'{suffix} not supported for token paths')
@@ -920,12 +929,10 @@ def validate_token_identifiers(token_dictionary):
             except KeyError:
                 e = CrossComputeConfigurationError(
                     f'{variable_id} is missing in the environment')
-                e.path = token_path
+                e.path = path
                 raise e
         identities_by_token[token] = identities
-    return {
-        'identities_by_token': identities_by_token,
-    }
+    return {'identities_by_token': identities_by_token}
 
 
 def validate_group_identifiers(group_dictionary):
